# AnthropicThinkingParam


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** |  | [optional] 
**budget_tokens** | **int** |  | [optional] 

## Example

```python
from arthur_client.api_bindings.models.anthropic_thinking_param import AnthropicThinkingParam

# TODO update the JSON string below
json = "{}"
# create an instance of AnthropicThinkingParam from a JSON string
anthropic_thinking_param_instance = AnthropicThinkingParam.from_json(json)
# print the JSON string representation of the object
print(AnthropicThinkingParam.to_json())

# convert the object into a dict
anthropic_thinking_param_dict = anthropic_thinking_param_instance.to_dict()
# create an instance of AnthropicThinkingParam from a dict
anthropic_thinking_param_from_dict = AnthropicThinkingParam.from_dict(anthropic_thinking_param_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


